@@ -11,42 +11,53 @@ import inspect
 import argparse
 import logging
 import os
+from os import path
 import re
+import imp
+import sys
 
 _CREDIT_LINE = "Powered by pynt - A Lightweight Python Build Tool."
 _LOGGING_FORMAT = "[ %(name)s - %(message)s ]"
 _TASK_PATTERN = re.compile("^([^\[]+)(\[([^\]]*)\])?$")
 #"^([^\[]+)(\[([^\],=]*(,[^\],=]+)*(,[^\],=]+=[^\],=]+)*)\])?$"
-def build(module,args):
+def build(args):
     """
     Build the specified module with specified arguments.
     
     @type module: module
     @type args: list of arguments
     """
-    
     # Build the command line.
     parser = _create_parser()
 
+    #No args passed. 
+    if not args: #todo: execute default task.
+        parser.print_help
+        exit
     # Parse arguments.
     args = parser.parse_args(args)
 
-    # Run task and all it's dependancies.
+    #load build file as a module
+    if not path.isfile(args.file):
+        raise Exception("Build file '%s' does not exist" % args.file) 
+    module = imp.load_source(path.splitext(path.basename(args.file))[0], args.file)
+    
+    # Run task and all it's dependencies.
     if args.list_tasks:
-        print_tasks(module)
+        print_tasks(module, args.file)
     elif not args.tasks:
         parser.print_help()
         print "\n"
-        print_tasks(module)
+        print_tasks(module, args.file)
     else:
         _run_from_task_names(module,args.tasks)
 
-def print_tasks(module):
+def print_tasks(module, file):
     # Get all tasks.
     tasks = _get_tasks(module)
     
     # Build task_list to describe the tasks.
-    task_list = "Tasks in build file %s:" % module.__file__
+    task_list = "Tasks in build file %s:" % file
     name_width = _get_max_name_length(module)+4
     task_help_format = "\n  {0:<%s} {1: ^10} {2}" % name_width
     for task in tasks:
@@ -81,8 +92,9 @@ def _get_task(module, name):
     matching_tasks = filter(lambda task: task.name.startswith(task_name), tasks)
         
     if not matching_tasks:
-        raise Exception("task should be one of " +
-                        ', '.join([task.name for task in tasks]))
+        raise Exception("Invalid task '%s'. Task should be one of %s" %
+                        (name, 
+                         ', '.join([task.name for task in tasks])))
     if len(matching_tasks) == 1:
         return matching_tasks[0], args, kwargs
     raise Exception("Conflicting matches %s for task %s " % (
@@ -158,6 +170,9 @@ def _create_parser():
                         metavar="task", nargs = '*')
     parser.add_argument('-l', '--list-tasks', help = "List the tasks",
                         action =  'store_true')
+    parser.add_argument('-f', '--file',
+                        help = "Build file to read the tasks from. 'build.py' is default value assumed if this argument is unspecified",
+                        metavar = "file", default =  "build.py")
     
     return parser
         
@@ -244,3 +259,6 @@ def _get_logger(module):
     logger.addHandler(ch)
 
     return logger
+
+def main():
+    build(sys.argv[1:])
\ No newline at end of file
